<?php
/**
 * @package Nicepage Website Builder
 * @author Nicepage https://www.nicepage.com
 * @copyright Copyright (c) 2016 - 2019 Nicepage
 * @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 or later
 */
defined('_JEXEC') or die;

/**
 * Class Com_NicepageInstallerScript
 */
class Com_NicepageInstallerScript
{
    /**
     * Custom install operations
     *
     * @param object $parent Parent object
     */
    public function install($parent) {
        jimport('joomla.filesystem.folder');
        jimport('joomla.filesystem.file');
        
        $src = JPATH_ROOT . '/administrator/components/com_nicepage/assets/images/nicepage-images';
        
        $this->createFolder(JPATH_ROOT . '/images/nicepage-images');
        
        JFile::copy($src . '/default-image.jpg', JPATH_ROOT . '/images/nicepage-images/default-image.jpg');
    }

    /**
     * Create folder by path
     *
     * @param string $path Path for creating
     *
     * @return bool
     */
    public function createFolder($path)
    {
        if (JFolder::create($path)) {
            if (!JFile::exists($path . '/index.html')) {
                JFile::copy(JPATH_ROOT . '/components/index.html', $path . '/index.html');
            }
            return true;
        }
        return false;
    }

    /**
     * Update action for installing
     *
     * @param object $parent Parent object
     */
    public function update($parent)
    {
        return $this->install($parent);
    }

    /**
     * Postflight method for joomla core
     *
     * @param string $type   Extension type
     * @param object $parent Parent object
     *
     * @return bool
     */
    public function postflight($type, $parent)
    {
        $db = JFactory::getDbo();

        // insert default params value
        $db->setQuery((string)'SELECT * FROM #__nicepage_params');
        $result = $db->loadResult();
        if (!$result) {
            $db->setQuery((string)'INSERT INTO #__nicepage_params (id, name, params) VALUES (1, \'com_nicepage\', \'{}\');');
            $db->execute();
        }
        // Update type for params column

        if ($db->name == 'postgresql' || $db->name == 'pgsql') {
            $db->setQuery((string)'ALTER TABLE #__nicepage_params ALTER COLUMN params TYPE text');
        } else {
            $db->setQuery((string)'ALTER TABLE #__nicepage_params MODIFY params mediumtext');
        }

        $db->execute();
        // Update url for link column
        $db->setQuery((string) 'UPDATE #__menu SET link = \'index.php?option=com_nicepage&task=nicepage.start\' WHERE title = \'COM_NICEPAGE\'');
        $db->execute();
        // Clear unused pages
        $db->setQuery((string) 'DELETE FROM #__nicepage_sections WHERE page_id not in (SELECT id from #__content)');
        $db->execute();
        return true;
    }
}