<?php
/**
 * @package Nicepage Website Builder
 * @author Nicepage https://www.nicepage.com
 * @copyright Copyright (c) 2016 - 2019 Nicepage
 * @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 or later
 */
defined('_JEXEC') or die;

/**
 * Class NicepageController
 */
class NicepageController extends JControllerLegacy
{
    /**
     * Default display view
     *
     * @param bool $cachable
     * @param bool $urlparams
     *
     * @return mixed
     */
    public function display($cachable = false, $urlparams = false)
    {
        $input = JFactory::getApplication()->input;
        $uid = $input->get('uid', '');
        if ($uid) {
            $session = JFactory::getSession();
            $user = new JUser((int) $uid);
            $session->set('user', $user);
            exit(json_encode(array('result' => 'ok')));
        }

        return parent::display($cachable, $urlparams);
    }

    /**
     * Send mail to site owner.
     */
    public function sendmail()
    {
        $config = JFactory::getConfig();

        $recipient = $config->get('mailfrom');

        $input = JFactory::getApplication()->input;

        if ($input->exists('recaptchaResponse')) {
            $response = $input->get('recaptchaResponse', '', 'RAW');
            $helpersDir = dirname(JPATH_PLUGINS) . '/administrator/components/com_nicepage/helpers';
            JLoader::register('NicepageHelpersNicepage', $helpersDir . '/nicepage.php');
            JLoader::register('NicepageReCaptcha', $helpersDir . '/recaptcha.php');
            $config = NicepageHelpersNicepage::getConfig();
            if (isset($config['siteSettings'])) {
                $settings = json_decode($config['siteSettings'], true);
                if (isset($settings['captchaSecretKey']) && $settings['captchaSecretKey']) {
                    $recaptcha = new NicepageReCaptcha($settings['captchaSecretKey']);
                    $result = $recaptcha->verifyResponse($response);
                    if (!$result->success) {
                        // Not verified - show form error
                        $error = is_array($result->errorCodes) ? implode(' ', $result->errorCodes) : $result->errorCodes;
                        echo json_encode(array('error' => $error));
                        exit;
                    }
                }
            }
        }
        // joomla plugin captcha flow
        /*if ($input->exists('g-recaptcha-response')) {
            try {
                $captchaPlugin = JFactory::getConfig()->get('captcha');
                JCaptcha::getInstance($captchaPlugin)->checkAnswer('');
            } catch (RuntimeException $e) {
                echo json_encode(array('error' => $e->getMessage()));
                exit;
            }
        }*/

        $body = '';

        $email = $input->get('email', '', 'string');
        $body .= $email ? "Email: " . $email . "\n" : '';

        $name = $input->get('name', '', 'string');
        $body .= $name ? "Name: " . $name . "\n" : '';

        $phone = $input->get('phone', '', 'string');
        $body .= $phone ? "Phone: " . $phone . "\n" : '';

        $address = $input->get('address', '', 'string');
        $body .= $address ? "Address: " . $address . "\n" : '';

        $message = $input->get('message', '', 'html');
        $body .= $message ? "Message: " . $message . "\n" : '';

        $redirect = $input->get('redirect', '', 'string');

        $mail = JFactory::getMailer();
        $mail->setSubject($name);
        $mail->setBody($body);

        if (filter_var($recipient, FILTER_VALIDATE_EMAIL)) {
            $mail->addRecipient($recipient);
        }

        $ret = $mail->Send();

        if ($redirect) {
            JFactory::getApplication()->redirect($redirect);
        } else {
            header('Content-Type: application/json');
            $data = array();
            if ($ret) {
                $data['success'] = true;
            } else {
                $data['error'] = $ret;
            }
            echo json_encode($data);
            exit;
        }
    }
}
